package com.hubspot.sprinter;

import java.security.InvalidParameterException;
import java.util.Collections;
import java.util.List;

import com.hubspot.utils.HubSpotIdentifiableObjectManager;
import com.hubspot.utils.db.DbUtils;
import com.hubspot.utils.db.HqlHelper;

/**
 * Manager for the Developer object.
 * 
 * @author dabdinoor
 */
public class DeveloperManager extends HubSpotIdentifiableObjectManager {
    /** Get Developer. */
    public Developer get(final Long id) {
        return (Developer) super.get(Developer.class, id);
    }

    /** Update Developer. */
    public boolean update(final Developer developer) {
        return super.update(developer);
    }

    /** Delete Developer. */
    public boolean delete(final Developer developer) {
        return super.delete(developer);
    }

    /** Save Developer. */
    public Developer save(final Developer developer) throws InvalidParameterException {
        if (developer.getDefaultPercentage() == null || developer.getDefaultPercentage() > 1
                || developer.getDefaultPercentage() < 0) {
            throw new InvalidParameterException("Developer default percentage is null or invalid.");
        }

        Long savedId = super.save(developer);
        return get(savedId);
    }

    /** List Developers. */
    public List<Developer> list() {
        String hql = "FROM Developer ORDER BY name";

        HqlHelper helper = DbUtils.createHqlHelper(getSessionFactory());
        List<Developer> result = helper.runHql(hql);
        if (result == null) {
            return Collections.EMPTY_LIST;
        }

        return result;
    }

    /** List Developers by their default team. */
    public List<Developer> listByDefaultTeamId(final Long defaultTeamId) {
        String hql = "FROM Developer WHERE defaultTeamId = " + defaultTeamId;

        HqlHelper helper = DbUtils.createHqlHelper(getSessionFactory());
        List<Developer> result = helper.runHql(hql);
        if (result == null) {
            return Collections.EMPTY_LIST;
        }

        return result;
    }
}
