package com.hubspot.sprinter;

import com.hubspot.utils.HubSpotIdentifiableObject;

/**
 * Represents the association for one developer in one sprint (i.e. Paul is on the Red Sox for Sprint 23b).
 * 
 * @author dabdinoor
 */
public class SprintTeamDeveloper extends HubSpotIdentifiableObject {
    private final SprintConstants sprintConstants = new SprintConstants();

    /** The sprint team. */
    private SprintTeam sprintTeam;

    /** The developer. */
    private Developer developer;

    /** The sprint. */
    private Sprint sprint;

    /** Number of vacation days for this developer this sprint. */
    private Double vacation;

    /** Developer percentage for this developer this sprint (i.e. new folks start at 33% and ramp up). */
    private Double percentage;

    /** Expected number of days for a single developer in the sprint. */
    public Double getNominal() {
        return sprintTeam.getSprintDays() * sprintConstants.getInnovationPercentage() * percentage;
    }

    /** Realized number of days for a single developer in the sprint (subtract vacations). */
    public Double getReal() {
        Double real = (sprintTeam.getSprintDays() - getVacation()) * sprintConstants.getInnovationPercentage()
                * percentage;
        return (real > 0) ? real : 0.0;
    }

    /**
     * @return the sprintTeam
     */
    public SprintTeam getSprintTeam() {
        return sprintTeam;
    }

    /**
     * @param sprintTeam
     *            the sprintTeam to set
     */
    public void setSprintTeam(SprintTeam sprintTeam) {
        this.sprintTeam = sprintTeam;
    }

    /**
     * @return the developer
     */
    public Developer getDeveloper() {
        return developer;
    }

    /**
     * @param developer
     *            the developer to set
     */
    public void setDeveloper(Developer developer) {
        this.developer = developer;
    }

    /**
     * @return the sprint
     */
    public Sprint getSprint() {
        return sprint;
    }

    /**
     * @param sprint
     *            the sprint to set
     */
    public void setSprint(Sprint sprint) {
        this.sprint = sprint;
    }

    /**
     * @return the sprintConstants
     */
    public SprintConstants getSprintConstants() {
        return sprintConstants;
    }

    /**
     * @return the vacation
     */
    public Double getVacation() {
        return vacation;
    }

    /**
     * @param vacation
     *            the vacation to set
     */
    public void setVacation(Double vacation) {
        this.vacation = vacation;
    }

    /**
     * @return the percentage
     */
    public Double getPercentage() {
        return percentage;
    }

    /**
     * @param percentage
     *            the percentage to set
     */
    public void setPercentage(Double percentage) {
        this.percentage = percentage;
    }
}
