package com.hubspot.sprinter;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.codehaus.plexus.util.StringUtils;

import com.hubspot.utils.HubSpotIdentifiableObjectManager;
import com.hubspot.utils.db.DbUtils;
import com.hubspot.utils.db.HqlHelper;

/**
 * Manager for the SprintTeam object.
 * 
 * @author dabdinoor
 */
public class SprintTeamManager extends HubSpotIdentifiableObjectManager {
    /** Get SprintTeam. */
    public SprintTeam get(final Long id) {
        return (SprintTeam) super.get(SprintTeam.class, id);
    }

    /** Update SprintTeam. */
    public boolean update(final SprintTeam sprintTeam) {
        return super.update(sprintTeam);
    }

    /** Delete SprintTeam. */
    public boolean delete(final SprintTeam sprintTeam) {
        return super.delete(sprintTeam);
    }

    /** Save SprintTeam. */
    public SprintTeam save(final SprintTeam sprintTeam) {
        if (!StringUtils.isEmpty(sprintTeam.getRemark()) && sprintTeam.getRemark().length() > 100) {
            sprintTeam.setRemark(sprintTeam.getRemark().substring(0, 100));
        }

        Long savedId = super.save(sprintTeam);
        return get(savedId);
    }

    /** List sprint teams by sprint ID. Includes hidden teams. */
    public List<SprintTeam> listBySprintId(final Long sprintId) {
        return listBySprintId(sprintId, true);
    }

    /**
     * List sprint teams by sprint ID.
     * 
     * @param includeHidden
     *            True if you want to get all teams including hidden teams.
     * */
    public List<SprintTeam> listBySprintId(final Long sprintId, final boolean includeHidden) {
        String hql = "FROM SprintTeam WHERE sprintId=" + sprintId;

        HqlHelper helper = DbUtils.createHqlHelper(getSessionFactory());
        List<SprintTeam> result = helper.runHql(hql);
        if (CollectionUtils.isEmpty(result)) {
            return Collections.EMPTY_LIST;
        }

        if (!includeHidden) {
            List<SprintTeam> keepers = new ArrayList<SprintTeam>(result.size());
            // only keep SprintTeams with a non-hidden team
            for (SprintTeam sprintTeam : result) {
                if (!sprintTeam.getTeam().getHide()) {
                    keepers.add(sprintTeam);
                }
            }
            result = keepers;
        }

        Collections.sort(result, teamComparator);

        return result;
    }

    /** Compares sprint teams by the team name. */
    private Comparator<SprintTeam> teamComparator = new Comparator<SprintTeam>() {
        @Override
        public int compare(final SprintTeam sprintTeam1, final SprintTeam sprintTeam2) {
            return sprintTeam1.getTeam().getName().compareTo(sprintTeam2.getTeam().getName());
        }
    };

    /**
     * List sprint teams by team ID.
     * 
     * */
    public List<SprintTeam> listByTeamId(final Long teamId) {
        String hql = "FROM SprintTeam WHERE teamId=" + teamId;

        HqlHelper helper = DbUtils.createHqlHelper(getSessionFactory());
        List<SprintTeam> result = helper.runHql(hql);
        if (CollectionUtils.isEmpty(result)) {
            return Collections.EMPTY_LIST;
        }

        Collections.sort(result, sprintComparator);

        return result;
    }

    /** Compares sprint teams by the sprint sequence. */
    private Comparator<SprintTeam> sprintComparator = new Comparator<SprintTeam>() {
        @Override
        public int compare(final SprintTeam sprintTeam1, final SprintTeam sprintTeam2) {
            return sprintTeam2.getSprint().getSequence().compareTo(sprintTeam1.getSprint().getSequence());
        }
    };
}
