package com.hubspot.sprinter;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import org.apache.commons.collections.CollectionUtils;

import com.hubspot.utils.HubSpotIdentifiableObjectManager;
import com.hubspot.utils.db.DbUtils;
import com.hubspot.utils.db.HqlHelper;

/**
 * Manager for the SprintTeamStats object.
 * 
 * @author dabdinoor
 */
public class SprintTeamStatsManager extends HubSpotIdentifiableObjectManager {
    /** Get SprintTeamStats. */
    public SprintTeamStats get(final Long id) {
        return (SprintTeamStats) super.get(SprintTeamStats.class, id);
    }

    /** Get sprint team stats for sprint team Id. */
    public SprintTeamStats getBySprintTeamId(final Long sprintTeamId) {
        String hql = "FROM SprintTeamStats WHERE sprintTeamId=" + sprintTeamId;

        HqlHelper helper = DbUtils.createHqlHelper(getSessionFactory());
        return (SprintTeamStats) helper.runHqlUnique(hql);
    }

    /** Update SprintTeamStats. */
    public boolean update(final SprintTeamStats sprintTeamStats) {
        return super.update(sprintTeamStats);
    }

    /** Delete SprintTeamStats. */
    public boolean delete(final SprintTeamStats sprintTeamStats) {
        return super.delete(sprintTeamStats);
    }

    /** Save SprintTeamStats. */
    public SprintTeamStats save(final SprintTeamStats sprintTeamStats) {
        Long savedId = super.save(sprintTeamStats);
        return get(savedId);
    }

    /** Compares sprint team stats by the sprint sequence. */
    private Comparator<SprintTeamStats> sprintSequenceComparator = new Comparator<SprintTeamStats>() {
        public int compare(final SprintTeamStats sprintTeamStats1, final SprintTeamStats sprintTeamStats2) {
            return sprintTeamStats1.getSprint().getSequence().compareTo(sprintTeamStats2.getSprint().getSequence());
        }
    };

    /** List sprint team stats by team Id. */
    public List<SprintTeamStats> listByTeamId(final Long teamId) {
        String hql = "FROM SprintTeamStats WHERE teamId=" + teamId;

        HqlHelper helper = DbUtils.createHqlHelper(getSessionFactory());
        List<SprintTeamStats> result = helper.runHql(hql);
        if (CollectionUtils.isEmpty(result)) {
            return Collections.EMPTY_LIST;
        }

        Collections.sort(result, sprintSequenceComparator);

        return result;
    }

    /** List sprint team stats by sprint team Id. */
    public List<SprintTeamStats> listBySprintTeamId(final Long sprintTeamId) {
        String hql = "FROM SprintTeamStats WHERE sprintTeamId=" + sprintTeamId;

        HqlHelper helper = DbUtils.createHqlHelper(getSessionFactory());
        List<SprintTeamStats> result = helper.runHql(hql);
        if (CollectionUtils.isEmpty(result)) {
            return Collections.EMPTY_LIST;
        }

        return result;
    }
}
