package com.hubspot.sprinter.web;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.collections.CollectionUtils;

import com.hubspot.sprinter.Developer;
import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.Team;
import com.hubspot.webutils.scaffold.AuthScaffoldAction;

/**
 * Common backing action for the Sprinter web actions.
 * 
 * @author dabdinoor
 */
public class BaseAction extends AuthScaffoldAction {
    /** Map of team IDs and names. */
    private Map<Long, String> teamNames;

    /** Map of developer IDs and names. */
    private Map<Long, String> developerNames;

    /** Initialize the team name map. */
    private void initializeTeamNames() {
        List<Team> teams = ManagerUtils.getTeamManager().list(false);
        if (CollectionUtils.isEmpty(teams)) {
            teamNames = Collections.EMPTY_MAP;
            return;
        }

        // I want them to stay in order
        teamNames = new LinkedHashMap<Long, String>(teams.size());
        for (Team team : teams) {
            teamNames.put(team.getId(), team.getName());
        }
    }

    /** Map of team IDs and names. */
    public Map<Long, String> getTeamNames() {
        if (teamNames == null) {
            initializeTeamNames();
        }

        return teamNames;
    }

    /** Initialize the developer name map. */
    private void initializeDeveloperNames() {
        List<Developer> developers = ManagerUtils.getDeveloperManager().list();
        if (CollectionUtils.isEmpty(developers)) {
            developerNames = Collections.EMPTY_MAP;
            return;
        }

        // I want them to stay in order
        developerNames = new LinkedHashMap<Long, String>(developers.size());
        for (Developer developer : developers) {
            developerNames.put(developer.getId(), developer.getName());
        }
    }

    /** Map of developer IDs and names. */
    public Map<Long, String> getDeveloperNames() {
        if (developerNames == null) {
            initializeDeveloperNames();
        }

        return developerNames;
    }
}
