package com.hubspot.sprinter.web;

import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.commons.lang.StringUtils;

import com.hubspot.sprinter.Developer;
import com.hubspot.sprinter.ManagerUtils;

/**
 * Backs the developer edit screen.
 * 
 * @author dabdinoor
 */
public class DeveloperEditAction extends BaseAction {
    /** The ID of the developer being edited. */
    private Long id;

    /** The redirect location. */
    private String location = "admin";

    /** The developer being edited. */
    private Developer developer;

    /** POSTed developer name. */
    private String developerName;

    /** POSTed developer percentage. */
    private Integer percentage;

    /** POSTed developer team ID. */
    private Long teamId;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Update the sprint. */
    public String update() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        if (!developerName.equals(getDeveloper().getName())) {
            getDeveloper().setName(developerName);
        }

        if (!getAdjustedPercentage().equals(getDeveloper().getDefaultPercentage())) {
            getDeveloper().setDefaultPercentage(getAdjustedPercentage());
        }

        if (teamId == null) {
            getDeveloper().setDefaultTeamId(null);
        } else if (!teamId.equals(getDeveloper().getDefaultTeamId())) {
            getDeveloper().setDefaultTeamId(teamId);
        }

        if (ManagerUtils.getDeveloperManager().update(getDeveloper())) {
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Save new developer. */
    public String save() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        developer = new Developer();
        developer.setName(developerName);
        developer.setDefaultPercentage(getAdjustedPercentage());
        developer.setDefaultTeamId(teamId);

        if (ManagerUtils.getDeveloperManager().save(developer) != null) {
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Validate form inputs. */
    private void validateInputs() {
        if (StringUtils.isEmpty(developerName) || StringUtils.isBlank(developerName)) {
            addActionError("Name input was invalid.");
        }
        if (percentage == null || percentage < 0 || percentage > 100) {
            addActionError("Percentage input was invalid.");
        }
    }

    @Override
    public Map<Long, String> getTeamNames() {
        Map<Long, String> teams = new LinkedHashMap<Long, String>();
        teams.put(null, "No team");
        teams.putAll(super.getTeamNames());
        return teams;
    }

    /** Since the POSTed value is an integer we need to divide by 100. */
    private Double getAdjustedPercentage() {
        return Double.valueOf(percentage) / 100;
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(final Long id) {
        this.id = id;
    }

    /**
     * @return the developer
     */
    public Developer getDeveloper() {
        if (developer == null) {
            developer = ManagerUtils.getDeveloperManager().get(id);
        }
        return developer;
    }

    /**
     * @return the developerName
     */
    public String getDeveloperName() {
        return developerName;
    }

    /**
     * @param developerName
     *            the developerName to set
     */
    public void setDeveloperName(final String developerName) {
        this.developerName = developerName;
    }

    /**
     * @return the percentage
     */
    public Integer getPercentage() {
        return percentage;
    }

    /**
     * @param percentage
     *            the percentage to set
     */
    public void setPercentage(final Integer percentage) {
        this.percentage = percentage;
    }

    /**
     * @return the teamId
     */
    public Long getTeamId() {
        return teamId;
    }

    /**
     * @param teamId
     *            the teamId to set
     */
    public void setTeamId(final Long teamId) {
        this.teamId = teamId;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }
}
