package com.hubspot.sprinter.web;

import org.apache.commons.lang.StringUtils;

import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.Sprint;

/**
 * Backs the sprint edit screen.
 * 
 * @author dabdinoor
 */
public class SprintEditAction extends BaseAction {
    /** The ID of the sprint being edited. */
    private Long id;

    /** The redirect location. */
    private String location = "admin";

    /** The sprint being edited. */
    private Sprint sprint;

    /** POSTed sprint name. */
    private String sprintName;

    /** POSTed sprint sequence. */
    private Integer sequence;

    /** POSTed default days. */
    private Double defaultDays;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Update the sprint. */
    public String update() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        if (!sprintName.equals(getSprint().getName())) {
            getSprint().setName(sprintName);
        }

        if (!sequence.equals(getSprint().getSequence())) {
            getSprint().setSequence(sequence);
        }

        if (!defaultDays.equals(getSprint().getDefaultDays())) {
            getSprint().setDefaultDays(defaultDays);
        }

        if (ManagerUtils.getSprintManager().update(getSprint())) {
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Save new sprint. */
    public String save() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        sprint = new Sprint();
        sprint.setName(sprintName);
        sprint.setSequence(sequence);
        sprint.setDefaultDays(defaultDays);

        if (ManagerUtils.getSprintManager().create(sprint)) {
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Destroys a sprint. */
    public String destroy() {
        if (ManagerUtils.getSprintManager().destroy(getSprint())) {
            return SUCCESS;
        }

        addActionError("Destroy failed.");

        return ERROR;
    }

    /** Validate form inputs. */
    private void validateInputs() {
        if (StringUtils.isEmpty(sprintName) || StringUtils.isBlank(sprintName)) {
            addActionError("Name input was invalid.");
        }
        if (sequence == null || sequence < 0) {
            addActionError("Sequence input was invalid.");
        }
        if (defaultDays == null || defaultDays < 0) {
            addActionError("Default days input was invalid.");
        }
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return the sprint
     */
    public Sprint getSprint() {
        if (sprint == null) {
            sprint = ManagerUtils.getSprintManager().get(id);
        }
        return sprint;
    }

    /**
     * @return the sprintName
     */
    public String getSprintName() {
        return sprintName;
    }

    /**
     * @param sprintName
     *            the sprintName to set
     */
    public void setSprintName(String sprintName) {
        this.sprintName = sprintName;
    }

    /**
     * @return the sequence
     */
    public Integer getSequence() {
        return sequence;
    }

    /**
     * @param sequence
     *            the sequence to set
     */
    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }

    /**
     * @return the defaultDays
     */
    public Double getDefaultDays() {
        return defaultDays;
    }

    /**
     * @param defaultDays
     *            the defaultDays to set
     */
    public void setDefaultDays(Double defaultDays) {
        this.defaultDays = defaultDays;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }
}
