package com.hubspot.sprinter.web;

import java.util.List;

import org.codehaus.plexus.util.StringUtils;

import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.SprintConstants;
import com.hubspot.sprinter.SprintTeam;
import com.hubspot.sprinter.SprintTeamDeveloper;
import com.hubspot.sprinter.SprintTeamStats;

/**
 * Backs the sprint team plan screen.
 * 
 * @author dabdinoor
 */
public class SprintPlanAction extends BaseAction {
    /** The ID of the sprint team being viewed. */
    private Long id;

    /** The sprint team being viewed. */
    private SprintTeam sprintTeam;

    /** The stats for sprint team. */
    private SprintTeamStats sprintTeamStats;

    /** The list of all developers to display. */
    private List<SprintTeamDeveloper> developers;

    // TODO
    private final SprintConstants sprintConstants = new SprintConstants();

    @Override
    public String execute() throws Exception {
        if (getSprintTeamStats() == null) {
            // stats do not exist for this, which should not happen, but create them anyway
            sprintTeamStats = new SprintTeamStats();
            sprintTeamStats.setSprint(getSprintTeam().getSprint());
            sprintTeamStats.setTeam(getSprintTeam().getTeam());
            sprintTeamStats.setSprintTeam(getSprintTeam());
            sprintTeamStats.setPlannedPoints(0);
            sprintTeamStats.setCompletedPoints(0);
            sprintTeamStats.setPlannedStories(0);
            sprintTeamStats.setCompletedStories(0);
            sprintTeamStats.setDeveloperDays(0.0);
            sprintTeamStats = ManagerUtils.getSprintTeamStatsManager().save(sprintTeamStats);
        }

        return SUCCESS;
    }

    /** Get the remarks for this sprint plan. */
    public String getComment() {
        if (StringUtils.isEmpty(getSprintTeam().getRemark())) {
            return "Add comment?";
        }

        return getSprintTeam().getRemark();
    }

    /**
     * @return the developers
     */
    public List<SprintTeamDeveloper> getDevelopers() {
        if (developers == null) {
            developers = ManagerUtils.getSprintTeamDeveloperManager().list(id);
        }
        return developers;
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return the sprint team
     */
    public SprintTeam getSprintTeam() {
        if (sprintTeam == null) {
            sprintTeam = ManagerUtils.getSprintTeamManager().get(id);
        }
        return sprintTeam;
    }

    /**
     * @return the sprintConstants
     */
    public SprintConstants getSprintConstants() {
        return sprintConstants;
    }

    /**
     * @return the sprintTeamStats
     */
    public SprintTeamStats getSprintTeamStats() {
        if (sprintTeamStats == null) {
            sprintTeamStats = ManagerUtils.getSprintTeamStatsManager().getBySprintTeamId(id);
        }
        return sprintTeamStats;
    }
}
