package com.hubspot.sprinter.web;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.Sprint;
import com.hubspot.sprinter.SprintTeam;
import com.hubspot.sprinter.Team;

/**
 * Backs the add team to sprint screen.
 * 
 * @author dabdinoor
 */
public class SprintTeamAddAction extends BaseAction {
    /** The ID of the team. */
    private Long id;

    /** The redirect location. */
    private String location;

    /** The team. */
    private Team team;

    /** POSTed sprint ID. */
    private Long sprintId;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Save the changes. */
    public String save() {
        Sprint sprint = ManagerUtils.getSprintManager().get(sprintId);
        if (sprint == null) {
            addActionError("Invalid sprint selection.");
            return ERROR;
        }

        SprintTeam sprintTeam = new SprintTeam();
        sprintTeam.setSprint(sprint);
        sprintTeam.setTeam(getTeam());
        sprintTeam.setSprintDays(sprint.getDefaultDays());
        sprintTeam.setVelocity(getTeam().getAverageVelocity());

        if (ManagerUtils.getSprintTeamManager().save(sprintTeam) != null) {
            location = "view?id=" + id;
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Get the sprint names that are not already set up for this team. */
    public Map<Long, String> getSprintNames() {
        List<Sprint> sprints = ManagerUtils.getSprintManager().list();

        Map<Long, String> sprintNames = new LinkedHashMap<Long, String>(sprints.size());
        for (Sprint sprint : sprints) {
            sprintNames.put(sprint.getId(), sprint.getName());
        }

        List<SprintTeam> sprintTeams = ManagerUtils.getSprintTeamManager().listByTeamId(getId());
        for (SprintTeam sprintTeam : sprintTeams) {
            sprintNames.remove(sprintTeam.getSprint().getId());
        }

        return sprintNames;
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(final Long id) {
        this.id = id;
    }

    /**
     * @return the team
     */
    public Team getTeam() {
        if (team == null) {
            team = ManagerUtils.getTeamManager().get(id);
        }
        return team;
    }

    /**
     * @return the sprintId
     */
    public Long getSprintId() {
        return sprintId;
    }

    /**
     * @param sprintId
     *            the sprintId to set
     */
    public void setSprintId(final Long sprintId) {
        this.sprintId = sprintId;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }
}
