package com.hubspot.sprinter.web;

import com.hubspot.sprinter.Developer;
import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.SprintTeam;
import com.hubspot.sprinter.SprintTeamDeveloper;

/**
 * Backs the sprint team developer add screen.
 * 
 * @author dabdinoor
 */
public class SprintTeamDeveloperAddAction extends BaseAction {
    /** The ID of the sprint team. */
    private Long id;

    /** The redirect location. */
    private String location;

    /** The sprint team. */
    private SprintTeam sprintTeam;

    /** POSTed developer ID. */
    private Long developerId;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Save the changes. */
    public String save() {
        Developer developer = ManagerUtils.getDeveloperManager().get(developerId);
        if (developer == null) {
            addActionError("Invalid developer selection.");
            return ERROR;
        }

        SprintTeamDeveloper sprintTeamDeveloper = new SprintTeamDeveloper();
        sprintTeamDeveloper.setDeveloper(developer);
        sprintTeamDeveloper.setSprintTeam(getSprintTeam());
        sprintTeamDeveloper.setSprint(getSprintTeam().getSprint());
        sprintTeamDeveloper.setPercentage(developer.getDefaultPercentage());
        sprintTeamDeveloper.setVacation(0.0);

        if (ManagerUtils.getSprintTeamDeveloperManager().save(sprintTeamDeveloper) != null) {
            location = "plan?id=" + id;
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return the sprint
     */
    public SprintTeam getSprintTeam() {
        if (sprintTeam == null) {
            sprintTeam = ManagerUtils.getSprintTeamManager().get(id);
        }
        return sprintTeam;
    }

    /**
     * @return the developerId
     */
    public Long getDeveloperId() {
        return developerId;
    }

    /**
     * @param developerId
     *            the developerId to set
     */
    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }
}
