package com.hubspot.sprinter.web;

import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.SprintTeamDeveloper;

/**
 * Backs the sprint team developer edit screen.
 * 
 * @author dabdinoor
 */
public class SprintTeamDeveloperEditAction extends BaseAction {
    /** The ID of the sprint team developer being edited. */
    private Long id;

    /** The redirect location. */
    private String location;

    /** The ID of the sprint plan. */
    private Long planId;

    /** The sprint team developer being edited. */
    private SprintTeamDeveloper sprintTeamDeveloper;

    /** POSTed vacation days. */
    private Double vacation;

    /** POSTed developer percentage. */
    private Integer percentage;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Save the changes. */
    public String update() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        if (!vacation.equals(getSprintTeamDeveloper().getVacation())) {
            getSprintTeamDeveloper().setVacation(vacation);
        }
        if (!getAdjustedPercentage().equals(getSprintTeamDeveloper().getPercentage())) {
            getSprintTeamDeveloper().setPercentage(getAdjustedPercentage());
        }

        if (ManagerUtils.getSprintTeamDeveloperManager().update(getSprintTeamDeveloper())) {
            location = "plan?id=" + getSprintTeamDeveloper().getSprintTeam().getId();
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Delete the sprint team developer. */
    public String delete() {
        if (ManagerUtils.getSprintTeamDeveloperManager().delete(getSprintTeamDeveloper())) {
            location = "plan?id=" + getSprintTeamDeveloper().getSprintTeam().getId();
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Validate form inputs. */
    private void validateInputs() {
        if (vacation == null || vacation < 0) {
            addActionError("Vacation input was invalid.");
        }
        if (percentage == null || percentage < 0 || percentage > 100) {
            addActionError("Percentage input was invalid.");
        }
    }

    /** Since the POSTed value is an integer we need to divide by 100. */
    private Double getAdjustedPercentage() {
        return Double.valueOf(percentage) / 100;
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return the sprint team developer
     */
    public SprintTeamDeveloper getSprintTeamDeveloper() {
        if (sprintTeamDeveloper == null) {
            sprintTeamDeveloper = ManagerUtils.getSprintTeamDeveloperManager().get(id);
        }
        return sprintTeamDeveloper;
    }

    /**
     * @return the planId
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * @param planId
     *            the planId to set
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    /**
     * @return the vacation
     */
    public Double getVacation() {
        return vacation;
    }

    /**
     * @param vacation
     *            the vacation to set
     */
    public void setVacation(Double vacation) {
        this.vacation = vacation;
    }

    /**
     * @return the percentage
     */
    public Integer getPercentage() {
        return percentage;
    }

    /**
     * @param percentage
     *            the percentage to set
     */
    public void setPercentage(Integer percentage) {
        this.percentage = percentage;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }
}
