package com.hubspot.sprinter.web;

import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.SprintTeam;

/**
 * Backs the sprint team edit screen.
 * 
 * @author dabdinoor
 */
public class SprintTeamEditAction extends BaseAction {
    /** The ID of the sprint team being edited. */
    private Long id;

    /** The redirect location. */
    private String location;

    /** The sprint team being edited. */
    private SprintTeam sprintTeam;

    /** POSTed sprint days. */
    private Double sprintDays;

    /** POSTed velocity. */
    private Double velocity;

    /** POSTed comment. */
    private String comment;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Save the changes. */
    public String update() {
        if (sprintDays == null || sprintDays <= 0) {
            addActionError("Days input was invalid.");
        }
        if (velocity == null || velocity <= 0) {
            addActionError("Story points input was invalid.");
        }
        if (hasActionErrors()) {
            return ERROR;
        }

        if (!sprintDays.equals(getSprintTeam().getSprintDays())) {
            getSprintTeam().setSprintDays(sprintDays);
        }

        if (!velocity.equals(getSprintTeam().getVelocity())) {
            getSprintTeam().setVelocity(velocity);
        }

        if (!comment.equals(getSprintTeam().getRemark())) {
            getSprintTeam().setRemark(comment);
        }

        if (ManagerUtils.getSprintTeamManager().update(getSprintTeam())) {
            location = "plan?id=" + id;
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return the sprint
     */
    public SprintTeam getSprintTeam() {
        if (sprintTeam == null) {
            sprintTeam = ManagerUtils.getSprintTeamManager().get(id);
        }
        return sprintTeam;
    }

    /**
     * @return the sprintDays
     */
    public Double getSprintDays() {
        return sprintDays;
    }

    /**
     * @param sprintDays
     *            the sprintDays to set
     */
    public void setSprintDays(Double sprintDays) {
        this.sprintDays = sprintDays;
    }

    /**
     * @return the velocity
     */
    public Double getVelocity() {
        return velocity;
    }

    /**
     * @param velocity
     *            the velocity to set
     */
    public void setVelocity(Double velocity) {
        this.velocity = velocity;
    }

    /**
     * @return the comment
     */
    public String getComment() {
        return comment;
    }

    /**
     * @param comment
     *            the comment to set
     */
    public void setComment(String comment) {
        this.comment = comment;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }
}
