package com.hubspot.sprinter.web;

import java.util.List;

import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.SprintTeamStats;
import com.hubspot.sprinter.Team;

/**
 * Backs the sprint team stats screen.
 * 
 * @author dabdinoor
 */
public class SprintTeamStatsEditAction extends BaseAction {
    /** The ID of the sprint team stats being viewed. */
    private Long id;

    /** The redirect location. */
    private String location;

    /** The sprint team stats being viewed. */
    private SprintTeamStats sprintTeamStats;

    /** The developer days from the plan. */
    private Double days;

    /** The available points days from the plan. */
    private Double points;

    /** POSTed developer days. */
    private Double developerDays;

    /** POSTed planned points. */
    private Integer plannedPoints;

    /** POSTed completed points. */
    private Integer completedPoints;

    /** POSTed planned stories. */
    private Integer plannedStories;

    /** POSTed completed stories. */
    private Integer completedStories;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Update sprint team stats. */
    public String update() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        if (!developerDays.equals(getSprintTeamStats().getDeveloperDays())) {
            getSprintTeamStats().setDeveloperDays(developerDays);
        }

        if (!plannedPoints.equals(getSprintTeamStats().getPlannedPoints())) {
            getSprintTeamStats().setPlannedPoints(plannedPoints);
        }

        if (!completedPoints.equals(getSprintTeamStats().getCompletedPoints())) {
            getSprintTeamStats().setCompletedPoints(completedPoints);
        }

        if (!plannedStories.equals(getSprintTeamStats().getPlannedStories())) {
            getSprintTeamStats().setPlannedStories(plannedStories);
        }

        if (!completedStories.equals(getSprintTeamStats().getCompletedStories())) {
            getSprintTeamStats().setCompletedStories(completedStories);
        }

        if (!ManagerUtils.getSprintTeamStatsManager().update(getSprintTeamStats())) {
            addActionError("Save failed.");
            return ERROR;
        }

        Team team = ManagerUtils.getTeamManager().get(getSprintTeamStats().getTeam().getId());
        if (team == null) {
            addActionError("Save failed.");
            return ERROR;
        }

        // calculate the new average
        List<SprintTeamStats> teamStats = ManagerUtils.getSprintTeamStatsManager().listByTeamId(team.getId());
        int count = 0;
        double total = 0;
        for (SprintTeamStats stats : teamStats) {
            double average = (stats.getDeveloperDays() > 0) ? stats.getCompletedPoints() / stats.getDeveloperDays()
                    : 0.0;
            // do not count zeroes in average
            if (average > 0) {
                count++;
                total += average;
            }
        }

        Double averageVelocity = (count > 0) ? total / count : 0.0;
        team.setAverageVelocity(averageVelocity);
        if (ManagerUtils.getTeamManager().update(team)) {
            location = "plan?id=" + getSprintTeamStats().getSprintTeam().getId();
            return SUCCESS;
        }

        addActionError("Save failed.");
        return ERROR;
    }

    /** Validate form inputs. */
    private void validateInputs() {
        if (plannedPoints == null || plannedPoints < 0) {
            addActionError("Committed points input invalid.");
        }
        if (completedPoints == null || completedPoints < 0) {
            addActionError("Completed points input invalid.");
        }
        if (plannedStories == null || plannedStories < 0) {
            addActionError("Committed stories input invalid.");
        }
        if (completedStories == null || completedStories < 0) {
            addActionError("Completed stories input invalid.");
        }
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(final Long id) {
        this.id = id;
    }

    /**
     * @return the sprintTeamStats
     */
    public SprintTeamStats getSprintTeamStats() {
        if (sprintTeamStats == null) {
            sprintTeamStats = ManagerUtils.getSprintTeamStatsManager().get(id);
        }
        return sprintTeamStats;
    }

    /**
     * @return the plannedPoints
     */
    public Integer getPlannedPoints() {
        return plannedPoints;
    }

    /**
     * @param plannedPoints
     *            the plannedPoints to set
     */
    public void setPlannedPoints(final Integer plannedPoints) {
        this.plannedPoints = plannedPoints;
    }

    /**
     * @return the completedPoints
     */
    public Integer getCompletedPoints() {
        return completedPoints;
    }

    /**
     * @param completedPoints
     *            the completedPoints to set
     */
    public void setCompletedPoints(final Integer completedPoints) {
        this.completedPoints = completedPoints;
    }

    /**
     * @return the days
     */
    public Double getDays() {
        return days;
    }

    /**
     * @param days
     *            the days to set
     */
    public void setDays(final Double days) {
        this.days = days;
    }

    /**
     * @return the points
     */
    public Double getPoints() {
        return points;
    }

    /**
     * @param points
     *            the points to set
     */
    public void setPoints(final Double points) {
        this.points = points;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }

    /**
     * @return the plannedStories
     */
    public Integer getPlannedStories() {
        return plannedStories;
    }

    /**
     * @param plannedStories
     *            the plannedStories to set
     */
    public void setPlannedStories(final Integer plannedStories) {
        this.plannedStories = plannedStories;
    }

    /**
     * @return the completedStories
     */
    public Integer getCompletedStories() {
        return completedStories;
    }

    /**
     * @param completedStories
     *            the completedStories to set
     */
    public void setCompletedStories(final Integer completedStories) {
        this.completedStories = completedStories;
    }

    /**
     * @return the developerDays
     */
    public Double getDeveloperDays() {
        return developerDays;
    }

    /**
     * @param developerDays
     *            the developerDays to set
     */
    public void setDeveloperDays(final Double developerDays) {
        this.developerDays = developerDays;
    }
}
