package com.hubspot.sprinter.web;

import org.apache.commons.lang.StringUtils;

import com.hubspot.sprinter.ManagerUtils;
import com.hubspot.sprinter.Team;

/**
 * Backs the team edit screen.
 * 
 * @author dabdinoor
 */
public class TeamEditAction extends BaseAction {
    /** The ID of the team being edited. */
    private Long id;

    /** The redirect location. */
    private String location = "admin";

    /** The team being edited. */
    private Team team;

    /** POSTed team name. */
    private String teamName;

    /** POSTed team hide status. */
    private Boolean teamHide;

    @Override
    public String execute() throws Exception {
        return SUCCESS;
    }

    /** Update the team. */
    public String update() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        if (!teamName.equals(getTeam().getName())) {
            getTeam().setName(teamName);
        }

        if (teamHide != null) {
            getTeam().setHide(teamHide);
        } else {
            // show by default
            getTeam().setHide(false);
        }

        if (ManagerUtils.getDeveloperManager().update(getTeam())) {
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Save new team. */
    public String save() {
        validateInputs();
        if (hasActionErrors()) {
            return ERROR;
        }

        team = new Team();
        team.setName(teamName);
        team.setAverageVelocity(0.0);
        team.setHide(false);

        if (ManagerUtils.getTeamManager().save(team) != null) {
            return SUCCESS;
        }

        addActionError("Save failed.");

        return ERROR;
    }

    /** Validate form inputs. */
    private void validateInputs() {
        if (StringUtils.isEmpty(teamName) || StringUtils.isBlank(teamName)) {
            addActionError("Name input was invalid.");
        }
    }

    /**
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(final Long id) {
        this.id = id;
    }

    /**
     * @return the team
     */
    public Team getTeam() {
        if (team == null) {
            team = ManagerUtils.getTeamManager().get(id);
        }
        return team;
    }

    /**
     * @return the teamName
     */
    public String getTeamName() {
        return teamName;
    }

    /**
     * @param teamName
     *            the teamName to set
     */
    public void setTeamName(final String teamName) {
        this.teamName = teamName;
    }

    public Boolean getTeamHide() {
        return teamHide;
    }

    public void setTeamHide(final Boolean teamHide) {
        this.teamHide = teamHide;
    }

    /**
     * @return the location
     */
    public String getLocation() {
        return location;
    }
}
