package com.hubspot.sprinter;

import java.util.List;

import com.hubspot.utils.BaseTest;

/**
 * Tests for the SprintManager.
 * 
 * @author dabdinoor
 */
public class SprintManagerTest extends BaseTest {
    SprintManager manager = new SprintManager();

    /** Test basic CRUD operations. */
    public void testCRUD() {
        Sprint sprint = manager.get(null);
        assertNull(sprint);

        sprint = new Sprint();
        sprint.setName("Test sprint");
        sprint.setSequence(10);
        sprint.setDefaultDays(5.0);

        Sprint saved = manager.save(sprint);
        assertNotNull(saved);

        saved.setName("shoes");

        boolean success = manager.update(saved);
        assertTrue(success);

        Sprint updated = manager.get(saved.getId());
        assertEquals("shoes", updated.getName());
        assertEquals(Integer.valueOf(10), updated.getSequence());

        success = manager.delete(updated);
        assertTrue(success);
    }

    /** Test the create and destroy of sprint and the sub-objects. */
    public void testCreateDestroy() {
        Sprint sprint = new Sprint();
        sprint.setName("Test sprint");
        sprint.setSequence(10);
        sprint.setDefaultDays(5.0);

        boolean result = manager.create(sprint);
        assertTrue(result);

        List<SprintTeam> sprintTeams = ManagerUtils.getSprintTeamManager().listBySprintId(sprint.getId());
        assertFalse(sprintTeams.isEmpty());

        result = manager.destroy(sprint);
        assertTrue(result);

        sprintTeams = ManagerUtils.getSprintTeamManager().listBySprintId(sprint.getId());
        assertTrue(sprintTeams.isEmpty());
    }
}
