package com.hubspot.sprinter;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;

import com.hubspot.utils.BaseTest;

/**
 * Tests for the SprintTeamManager.
 * 
 * @author dabdinoor
 */
public class SprintTeamManagerTest extends BaseTest {
    private Team team;
    private Sprint sprint;
    private Developer developer;

    /** Test basic CRUD operations. */
    public void testCRUD() {
        SprintTeamManager manager = new SprintTeamManager();

        SprintTeam sprintTeam = manager.get(null);
        assertNull(sprintTeam);

        sprintTeam = new SprintTeam();
        sprintTeam.setTeam(team);
        sprintTeam.setSprint(sprint);
        sprintTeam.setSprintDays(0.0);
        sprintTeam.setVelocity(0.0);

        SprintTeam saved = manager.save(sprintTeam);
        assertNotNull(saved);

        sprintTeam = manager.get(saved.getId());

        List<SprintTeam> sprintTeams = manager.listBySprintId(sprintTeam.getSprint().getId());
        assertFalse(CollectionUtils.isEmpty(sprintTeams));

        sprintTeams = manager.listByTeamId(sprintTeam.getTeam().getId());
        assertFalse(CollectionUtils.isEmpty(sprintTeams));

        // now test sprint team developer
        SprintTeamDeveloperManager sprintDevManager = new SprintTeamDeveloperManager();

        SprintTeamDeveloper sprintDev = new SprintTeamDeveloper();
        sprintDev.setDeveloper(developer);
        sprintDev.setSprint(sprint);
        sprintDev.setSprintTeam(sprintTeam);
        sprintDev.setVacation(0.0);
        sprintDev.setPercentage(1.0);

        SprintTeamDeveloper savedSprintDev = sprintDevManager.save(sprintDev);
        assertNotNull(savedSprintDev);
        assertEquals(developer.getId(), savedSprintDev.getDeveloper().getId());
        assertEquals(sprintTeam.getId(), savedSprintDev.getSprintTeam().getId());
        assertEquals(sprint.getId(), savedSprintDev.getSprint().getId());

        // clean up
        boolean success = sprintDevManager.delete(savedSprintDev);
        assertTrue(success);

        success = manager.delete(sprintTeam);
        assertTrue(success);
    }

    /** Test remark saving. */
    public void testRemark() {
        SprintTeamManager manager = new SprintTeamManager();

        SprintTeam sprintTeam = manager.get(null);
        assertNull(sprintTeam);

        sprintTeam = new SprintTeam();
        sprintTeam.setTeam(team);
        sprintTeam.setSprint(sprint);
        sprintTeam.setSprintDays(0.0);
        sprintTeam.setVelocity(0.0);
        // over 100 chars
        sprintTeam
                .setRemark("asl kdjfl wjelrj we asl kdjfl wjelrj we asl kdjfl wjelrj we asl kdjfl wjelrj we asl kdjfl wjelrj wee asl kdjfl wjelrj we");

        SprintTeam saved = manager.save(sprintTeam);
        assertNotNull(saved);

        sprintTeam = manager.get(saved.getId());
        // trimmed to 100 chars
        assertEquals(
                "asl kdjfl wjelrj we asl kdjfl wjelrj we asl kdjfl wjelrj we asl kdjfl wjelrj we asl kdjfl wjelrj wee",
                sprintTeam.getRemark());

        // clean up
        boolean success = manager.delete(sprintTeam);
        assertTrue(success);
    }

    @Override
    protected void setUp() throws Exception {
        sprint = new Sprint();
        sprint.setName("testsprint 0001");
        sprint.setSequence(-1);
        sprint.setDefaultDays(5.0);

        sprint = ManagerUtils.getSprintManager().save(sprint);
        assertNotNull(sprint);

        team = new Team();
        team.setName("awesome team");
        team.setAverageVelocity(1.0);
        team.setHide(false);

        team = ManagerUtils.getTeamManager().save(team);
        assertNotNull(team);

        developer = new Developer();
        developer.setName("test McTester");
        developer.setDefaultPercentage(1.0);

        developer = ManagerUtils.getDeveloperManager().save(developer);
        assertNotNull(developer);
    }

    @Override
    protected void tearDown() throws Exception {
        ManagerUtils.getSprintManager().delete(sprint);
        ManagerUtils.getTeamManager().delete(team);
        ManagerUtils.getDeveloperManager().delete(developer);
    }
}
