package com.hubspot.sprinter;

import com.hubspot.utils.BaseTest;

/**
 * Tests for the SprintTeamStatsManager.
 * 
 * @author dabdinoor
 */
public class SprintTeamStatsManagerTest extends BaseTest {
    private Team team;
    private Sprint sprint;
    private SprintTeam sprintTeam;

    /** Test basic CRUD operations. */
    public void testCRUD() {
        SprintTeamStatsManager manager = new SprintTeamStatsManager();

        SprintTeamStats stats = new SprintTeamStats();
        stats.setSprint(sprint);
        stats.setTeam(team);
        stats.setSprintTeam(sprintTeam);
        stats.setCompletedPoints(10);
        stats.setPlannedPoints(12);
        stats.setDeveloperDays(1.11);
        stats.setPlannedStories(0);
        stats.setCompletedStories(0);

        SprintTeamStats saved = manager.save(stats);
        assertNotNull(saved);

        saved.setCompletedPoints(5);
        boolean success = manager.update(saved);
        assertTrue(success);

        stats = manager.get(saved.getId());
        assertNotNull(stats);
        assertEquals(Integer.valueOf(5), stats.getCompletedPoints());

        success = manager.delete(stats);
        assertTrue(success);
    }

    @Override
    protected void setUp() throws Exception {
        sprint = new Sprint();
        sprint.setName("testsprint 0001");
        sprint.setSequence(-1);
        sprint.setDefaultDays(5.0);

        sprint = ManagerUtils.getSprintManager().save(sprint);
        assertNotNull(sprint);

        team = new Team();
        team.setName("awesome team");
        team.setAverageVelocity(1.0);
        team.setHide(false);

        team = ManagerUtils.getTeamManager().save(team);
        assertNotNull(team);

        sprintTeam = new SprintTeam();
        sprintTeam.setSprint(sprint);
        sprintTeam.setTeam(team);
        sprintTeam.setSprintDays(10.0);
        sprintTeam.setVelocity(2.2);

        sprintTeam = ManagerUtils.getSprintTeamManager().save(sprintTeam);
        assertNotNull(sprintTeam);
    }

    @Override
    protected void tearDown() throws Exception {
        ManagerUtils.getSprintManager().delete(sprint);
        ManagerUtils.getTeamManager().delete(team);
        ManagerUtils.getSprintTeamManager().delete(sprintTeam);
    }
}
